Classes (dsptoolbox.classes)
==============================

The main classes are listed here. For some filterbanks, special classes are used but the api works almost equally
as for the main FilterBank class.

Signal
-------------------------------------

.. automodule:: dsptoolbox.classes.signal
   :members:
   :special-members: [, __init__, ]
   :undoc-members:
   :show-inheritance:

ImpulseResponse
-------------------------------------

.. automodule:: dsptoolbox.classes.impulse_response
   :members:
   :special-members: [, __init__, ]
   :undoc-members:
   :show-inheritance:

MultiBandSignal
---------------------------------------

.. automodule:: dsptoolbox.classes.multibandsignal
   :members:
   :special-members: [, __init__, ]
   :undoc-members:
   :show-inheritance:

Filter
----------

.. automodule:: dsptoolbox.classes.filter
   :members:
   :special-members: [, __init__, ]
   :undoc-members:
   :show-inheritance:

Filterbank
----------------------------------

.. automodule:: dsptoolbox.classes.filterbank
   :members:
   :special-members: [, __init__, ]
   :undoc-members:
   :show-inheritance:
